.. Orange - Conformal Prediction documentation master file, created by
   sphinx-quickstart on Tue May 31 13:34:41 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Orange - Conformal Prediction's documentation!
=========================================================

.. toctree::
   :maxdepth: 4

   tutorial
   conformal


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

